function formattable(listbox,headers,varargin)
%FORMATTABLE Formats header and column data and displays it in a listbox
%
% formattable ( listbox, headers, column1, column2, ... )
%
% The first input must be a listbox handle.
% All other arguments are cell arrays of strings, where:
%   headers contains the title for each column, and
%   further arguments contain the data for each column.
% The number of header entries must equal the number of columns, and the
% length of each column must be the same. 
%
% EXAMPLE:
%
%     Create figure and list box
% 
%     f = figure('Name','HGTable Example','NumberTitle','off','Visible','off');
%     b = uicontrol('parent',f,'style','listbox',...
%         'Units','Normalized','Position',[0.1 0.1 0.8 0.8]);
% 
%
%     Create sample data from properties of list box
% 
%     Each column needs to be a cell array of strings. We'll have columns
%     for: property name, property data type, the size of the value for
%     that property, and lastly the value itself (if it is a string).
% 
%     p = get(b);
%     propnames = fieldnames(p);
%     datatype = cell(size(propnames));
%     datasize = cell(size(propnames));
%     stringdata = cell(size(propnames));
%     for i=1:numel(propnames)
%         v = get(b,propnames{i});
%         datatype{i} = class(v);
%         s = size(v);
%         datasize{i} = sprintf('%d*%d',s(1),s(2));
%         if ischar(v)
%             stringdata{i} = v;
%         else
%             stringdata{i} = '<not a string>';
%         end
%     end
%
%
%     Display data in list box
% 
%     The function "formattable" does everything for us. We could, if
%     necessary, format columns individually using "tablecolumn", join them
%     together using "tablestrings", and set that as the string for the
%     list box. 
% 
%     formattable(b,{'Property Name','Data Type','Data Size','Data'},...
%         propnames,datatype,datasize,stringdata);
%     set(f,'Visible','on');
%

% Written by Malcolm Wood - April 18, 2006
% Part of the HGTable package found in Mathwork's MATLAB Central -> File
% Exchange -> GUI Tools and Examples
%
