function comp = parsecsvline ( fid, delim )
% PARSECSVLINE parces a line from a CSV (comma separated value) file
% (typically exported from MS Excel) and return a cell array containing in
% each of its elements the values in the line pointed by the file pointer
% 'fid' based on their separation by the delimeter 'delim' (default ',').
%
% USAGE:    comp = parsecsvline ( fid )
%           comp = parsecsvline ( fid, delim )
%
% INPUT:    fid     the filepointer to the CSV file
%           delim   the delimeter used in the CSV file (optional)
%
% OUTPUT:   comp    a cell array containing all the 'delim' separated
%                   values in the current line
%
%
% EXAMPLE: Typically PARSECSVLINE can be used in a loop as shown below...
%
%           fid = fopen(filename,'r');
%           if fid ~= -1
%               comp = parsecsvline(fid, ','); % parse first line
%               while ~isempty(comp)
%                   <do something> ...
%                   comp = parsecsvline(fid, ',');  % parse next line
%               end
%           end
%           fclose(fid);
%
%   
% See also: FOPEN, CSVREAD, DLMREAD, XLSREAD, WK1READ
%
% K. Veropoulos
% kvero@dri.edu or k_veropoulos@freemail.gr
