function varargout = MSLibMan(varargin)
% MSLIBMAN (Mass Spectral Library Manager)
%   helps manage MS Library files of TEXT (*.MSD, *.SDF), MS EXCEL (*.CSV)
%   and their extended verions (*.???X, supported only in KV-Lib)
%   and MAT-file (*.SSL; Single Structure Library) file formats and
%   provides import/export and manual addition operations. 
%   
% USAGE: [ newMSLib ] = MSLibMan ( MSLib )
%
% INPUT: 
%   MSLib (optional)    can be a Matlab array of structures (see end of
%                       function description for details) or an existing
%                       library file of any of the above file formats; if
%                       no input is specified, MSLIBMAN will prompt the
%                       user to enter a filename which will be used when
%                       exporting newly created components in the library.
%
% OUTPUT:   
%   newMSLib (optional) this is a Matlab array of structures (see end of
%                       function description for details) which will be
%                       returned upon termination of MSLIBMAN, whether an
%                       import or export action was used or not.
%
%
% NOTE: The structure of the input or output variable is as follows for a
%       library of N components (showing <FieldName>: Description): 
%   
%   COMPONENT-SPECIFIC INFO (all supported formats):
%         Name: <Nx1 cell> array with ith element containing ith
%               component's name.
%      Formula: <Nx1 cell> array with ith element containing ith
%               component's formula.
%           MW: <1xN single> array with ith element containing ith
%               component's MW. 
%        CASNO: <1xN double> array with ith element containing ith
%               component's CAS (Chemical Abstracts Service) registry
%               number.
%      Comment: <Nx1 cell> array with ith element containing ith
%               component's comment.
%       PeakNo: <1xN single> array with ith element containing ith
%               component's recorded number of peaks.
%        Peaks: <Nx1 cell> array with ith element containing ith
%               component's recorded peaks as X-Y pairs (Ion-Abundance).
%               This is the component's reported Mass Spectrum (MS).
%
%   ADDITIONAL INTEGRATION/CALIBRATION METHOOD INFO (only in *.???X):
%           RT: <1xN single> array with ith element containing ith
%               component's expected retention time (RT).
%        RTstd: <1xN single> array with ith element containing ith
%               component's expected retention time standard deviation.
%       RTplus: <1xN single> array with ith element containing ith
%               component's search window ahead expected retention time
%               (RT).
%      RTminus: <1xN single> array with ith element containing ith
%               component's search window behind expected retention time
%               (RT).
%     QuantIon: <NxM cell> array with ith element containing ith
%               component's M quantified ion(s).
%  QuantIonUse: <NxM cell> array with ith element containing ith
%               component's indicator of how and which M quantified ion(s)
%               will be used. If numeric, then this value indicates which
%               ion will be used from the M quantified ion(s), e.g. if 2
%               then the 2nd ion from thhe list of M quantified ions will
%               be used for quantification. If 'Summed' or 'Averaged' then
%               the M quantified ions will be summed or averaged,
%               respectively, before quantification is performed.
%      QualIon: <NxM cell> array with ith element containing ith
%               component's M qualifying ion(s).
%      ExclIon: <NxM cell> array with ith element containing ith
%               component's M excuded ion(s).
% MatchFactReq: <1xN single> array with ith element containing ith
%               component's matching factor requirement (minimum %
%               similarity) for a positive component identification.
%               Separate definition of a matching factor for each component
%               provides the user with better flexibility to allow for
%               different margins of matching error, depending on the
%               complexity of the component's mass spectrum.
%  CalibrSlope: <1xN single> array with ith element containing ith
%               component's calibration slope.
%    CalibrInt: <1xN single> array with ith element containing ith
%               component's calibration intercept.
%          LQL: <1xN single> array with ith element containing ith
%               component's lower quantifiable limit (in ng).
%
%   ADDITIONAL MS INFO (all supported formats):
%      maxIon: <Nx1 cell> array with ith element containing ith component's
%              recorded ions in descending order of relative abundance.
%
%
% See also ReadMSLib, WriteMSLib
%
% Written by K. Veropoulos
% All Rights Reserved  07-30-07
