function score = MSscore ( MS1, MS2, varargin )
% MSSCORE computes the similarity score between two mass spectra (MS) based
% on different methods as defined by the input parameter 'method' (see
% below for details.
%
% USAGE:    score = MSscore ( MS1, MS2 )
%    or     score = MSscore ( MS1, MS2, ...
%                   'ParameterName', ParameterValue, ... )
%
% INPUT:    
%   MS1, MS2    the two MS to be compared (1xN vectors or Nx2 matrices).
%
%   Parameters   | Values ( default values in {} )
%   -------------+---------------------------------------------------------
%   Method       | absdist | euclidean | dot | xcorr | stein_scott |
%                |          {shimadzu} | gan | gan0
%                +---------------------------------------------------------
%                | Description: (Library Search Algorithm)
%                | Method to use for computing similarity index.
%   -------------+---------------------------------------------------------
%   WeightedInt  | true | false | 1 | {0}
%                |---------------------------------------------------------
%                | Description: (Weighted Intensity)
%                | use mass weighting. This is reported as an important
%                | optimization approach for the search algorithm. The
%                | resulting weighted intensity W is computed as (see ref 2)
%                | W = [Peak Intensity]^IntPower * [Mass]^MassPower.
%   -------------+---------------------------------------------------------
%   Verbose      | true | false | {1} | 0
%                |---------------------------------------------------------
%                | Description: 
%                | display up to top 20 matches.
%
% OUTPUT
%   score           similarity score
%
%
% References:
% 1. Gan, F., Yang J.-H. and Liang Y.-Z. (2001). "Library Search of Mass
%    Spectra with a New Matching Algorithm Based on Substructure
%    Similarity". Anal. Sciences, May 2001, Vol. 17, pp.635-638, Jap Soc
%    Anal. Chem.
% 2. Stein, S.E. and Scott, D.R. (1994). "Optimization and Testing of Mass
%    Spectral Library Search Algorithms for Compound Identification". J Am
%    Soc Mass Spectrom 1994, 5, 895-866.
% 3. Hertz, H.S., Hites, R.A. and Biemann, K. (1971). Anal. Chem. 1971, 43,
%    681-691.
%
% See also ReadMSLib, WriteMSLib, MSLibMan, MSLibMatch
%
% Written by K. Veropoulos
% All Rights Reserved  March 31, 2008
%
