function [ LibName, FileName, PathName ] = ReadMSLib(filename, mode)
%READMSLIB reads a Mass Spectral library file that is in MSP, SDF, CSV (and
%          their extended versions MSPX, SDFX, CSVX supported only in
%          KV_Lib; see NOTES below) or SSL (Single Structure Library)
%          format (KV_Lib based format) and returns a structured array or
%          array of structures in 'LibName' (depending on 'mode').
%
% USAGE:    [ LibName, FileName, PathName ] = ReadMSLib(filename, mode)
%
% INPUT:
%           filename    the filename of the MS library. 'filename' input
%                       options:
%                       - empty string (default), the user will be prompted
%                         to select an existing MS library file for
%                         reading; 
%                       - not an existing file, READMSLIB will simply
%                         return an empty library array organized according
%                         to 'mode' and FileName and PathName as zeros;
%                       - given the string value 'newlib', the user will be
%                         prompted to enter a new filename and an empty
%                         library array organized according to 'mode' will
%                         be returned together with the FileName and
%                         PathName of the new library to be created (NOTE:
%                         the file won't be created until after you add new
%                         compounds to the library and choose to export
%                         them to a file, at which point you can also
%                         change the filename and path of the new library.
%
%           mode        'plane' or 'element' which specifies whether the
%                       output structure array 'LibName' will be in plane
%                       or element-by-element organization, respectively.
%                       ( For more details refer to documentation under
%                         Programming -> Data Types -> Structures ->
%                         Organizing Data in Structure Arrays. )
%
% OUTPUT:
%           LibName     the output variable that will hold the resulting MS
%                       library.
%           FileName    the filename of the loaded library.
%           PathName    the path to the library file.
%
% NOTES:
%           File Format Content (default values in {})
%           -----------+---------------------------------------------------
%           MSP, SDF   |NIST Text Library Files with component info (Name,
%                      |Formula, MW, CAS #, Comment, Num. of Peaks, Peaks)
%           -----------+---------------------------------------------------
%           CSV        |Comma Separated Value format Library Files
%                      |(readable by Microsoft Excel) containing component
%                      |info (Name, Formula, MW, CAS #, Comment, Num. of
%                      |Peaks, Peaks)
%           -----------+---------------------------------------------------
%           MSPX, SDFX |Component info included in the above formats +
%           CSVX  	   |additional peak integration/calibration method info
%           SSL        |for each component:
%					   |	Expected RT, 
%					   |	Quantified Ion(s),
%                      |	Qualifying Ion(s), 
%					   |	Excluded Ion(s), 
%					   |	Matching Factor Requirement for a positive 
%					   |		component identification, {90}
%					   |	Calibration Slope, {0}
%					   |					Intercept, {0}
%					   |					Levels,
%					   |					Peak Areas,
%					   |					Peak Heights,
%					   |	Lower Quantifiable Limit (LQL), 
%					   |	maximum Ion,
%					   |	Internal Standard (IS) flag, ({0}: no, 1: yes)
%					   |	Group (such as PAH, n-Alkane, Phthalate, etc.)
%           -----------+---------------------------------------------------
%
%
% See also MSLibMan, WriteMSLib, documentation under Programming:Data Types:Structures:Organizing Data in Structure Arrays
%
% Written by K. Veropoulos
% All Rights Reserved  3/4/2008
