function [ ROC, ConfM, FIDs ] = PerfTable ( D, Gids, Qids, thresh, Glabels, Qlabels )
%function PerfTable: Performance Table
%   [ ROC, ConfM, FIDs ] = PerfTable ( D, Gids, Qids, thresh, Glabels, Qlabels )
%
% INPUT:
%       D:          distance matrix between the Query 'Q' and Gallery 'G' sets. 
%                   D(i,j) corresponds to the distance of Q(:,i) from G(:,j).
%       Gids:       IDs (persons) in 'G'.
%       Qids:       IDs (persons) in 'Q'.
%       thresh:     vector with threshold values.
%       Glabels:    labels (class ID) in 'G' (for class-specific
%                   verification - optional).
%       Qlabels:    labels (class ID) in 'Q' (for class-specific
%                   verification - optional).
%
% OUTPUT:
%       ROC:        ROC points matrix (FP rate used for x-axis, Accuracy
%                   rate used for y-axis) .
%       ConfM:      Confusion Matrix (in no of cases, i.e. no percentages).
%       FIDs:       FIDs (False IDs) is a 5-column matrix containing
%                   information about all queries that were erroneous.
%
%                   Column 1: Query ID  
%                   Column 2: Gallery ID (-1 when query mis-IDed or IDed as
%                             imposter)
%                   Column 3: Query class
%                   Column 4: Gallery class (-1 when query IDed as imposter)
%                   Column 5: error type;
%                       0 - genuine correctly IDed
%                       1 - genuine mis-IDed
%                       2 - genuine wrongly IDed as imposter 
%                       3 - imposter wrongly IDed as genuine
%                       4 - imposter correctly IDed as imposter
%
%                   Note: When 'Glabels' and 'Qlabels' are no specified
%                       (ie. empty sets) columns 3 and 4 are obsolete and
%                       the error type is shown in column 3.
%
%
% K. Veropoulos (k_veropoulos@freemail.gr)
% last updated Sep 22, 2006
