function [ scaled, range ] = Scale(Data, Lower, Upper)
% SCALE scales the elements of all the column vectors in
% the range of [Lower Upper]. (default [-1 1])
%
% USAGE:    [ scaled, range ] = Scale(Data);
%           [ scaled, range ] = Scale(Data, Lower, Upper);
% 
% INPUT:    Data    the MxN data matrix to be scaled (M samples x N
%                   variables to do a feature-based scaling; use transpose
%                   to do a sample-based scaling).
%           Lower   the target lower limit for the data (default -1).
%           Upper   the target upper limit for the data (default 1).
%
% OUTPUT:   scaled  the resulting scaled data.
%           range   a 1x3 cell array containing the Lower and Upper target
%                   limits of the scaling in the first element and the
%                   minimum and maximum values of each variable (or each
%                   sample if transposed Data is used) in the second and
%                   third elements, respectively; this variable can be used
%                   as input in the 'Scale2' function for scaling a test
%                   set based on the minimum and maximum values of a
%                   training set as scaled with 'Scale'.
%
%
% See also: SCALE2
%
% K. Veropoulos
% kvero@dri.edu or k_veropoulos@freemail.gr
