function [ model_fs, selfeat, featscores ] = csvm_fs (Ttr, tr, varargin)
%CSVM_FS finds best feature subset and performs an optimized C-SVM training
%on the data set 'tr' using only the selected features.
%
% USAGE:    [ model_fs, selfeat, featscores ] = csvm_fs ( Ttr, tr )
%           [ model_fs, selfeat, featscores ] = csvm_fs ( Ttr, tr,
%               'PropertyName', PropertyValue, ... )  
%
% INPUT:    tr  - input samples (a MxN matrix of N samples of M variables)
%           Ttr - target values for each sample (a Nx1 matrix of N target
%                 values)
%           Properties (optional): Names -- Values
%           'C'         -- range of values for parameter C (cost) of C-SVC,
%                          epsilon-SVR, and nu-SVR in LibSVM as base 2
%                          exponents for use with function 'csvm_opt'
%                          (default range: [-5:15])
%               example: model_opt = csvm_opt ( Ttr, tr, 'C', [-5:15])
%                  % will use 2^(-5), 2^(-4), ..., 2^14, 2^15 for C
%           'gamma'     -- range of values for parameter C (cost) of C-SVC,
%                          epsilon-SVR, and nu-SVR in LibSVM as base 2
%                          exponents for use with function 'csvm_opt'
%                          (default range: [-15:3])
%               example: model_opt = csvm_opt ( Ttr, tr, 'gamma', [-15:3])
%                  % will use 2^(-15), 2^(-14), ..., 2^2, 2^3 for gamma
%           'lookahead' -- number of additional features to add in current
%                          feature subset to look ahead for better
%                          performance compared to performance encoutered
%                          until current point (default value: 5)
%           'quitemode' -- flag for output display. Values:
%                       'off'   display progress and results (default)
%                       'on'    use quite mode (do not display anything)
%
%   NOTE: if both C and gamma ranges are given scalars instead of vectors,
%         no optimization will be performed
%
% OUTPUT:   model_fs   - optimised SVM model on the best feature subset for
%                        the predictor to be used with function 'svm_predict'
%           selfeat    - selected feature subset (index list sorted in
%                        descending order of feature discriminative
%                        significance)
%           featscores - a Mx2 matrix containing 2 columns: column 1
%                        contains the features' indices in descending
%                        order of discriminative significance (from the
%                        most discriminant to the least discriminant
%                        feature) and column 2 contains the discrimination
%                        scores for all features in the same order
%
% Ref: "A Practical Guide to Support Vector Classification"
%       by Chih-Wei Hsu, Chih-Chung Chang, and Chih-Jen Lin
%       (http://www.csie.ntu.edu.tw/~cjlin/papers/guide/guide.pdf)
%
%
% See also: CSVM_OPT, FEATSELS
%
% K. Veropoulos
% kvero@dri.edu or k_veropoulos@freemail.gr
