function [ W, b, Sw, Sb, eigval, tr_mean ] = lda( tr, Ttr, K )
% LDA Linear Discriminant Analysis.
% 
% USAGE: [ W, b, Sw, Sb, eigval, tr_mean ] = lda( tr, Ttr, K )
%
% Description:
%  This function is implementation of Linear Discriminant Analysis.
%  The goal is to train the linear transform which maximizes ratio 
%  between-class and within-class scatter matrix of projected 
%  data.
%
% Input:
%   tr [dim x num_data] Data sample.
%   Ttr [1 x num_data] Labels (1,2,...,nclass).
%
%   K [1x1] Output data dimension (default K = dim).
%
% Ouput:
%   W [dim x new_dim] Projection matrix.
%   b [new_dim x 1] Biases (projected mean of the training set).
%
%   tr_mean [dim x 1] Mean value of data.
%   Sw [dim x dim] Within-class scatter matrix.
%   Sb [dim x dim] Between-class scatter matrix.
%   eigval [dim x 1] Eigenvalues.
%
% See also: EIG, EIGS, EIGS2, PRINCOMP, PCAS, PCACOV, PCARES, KPCA1, KPCA2,
%           PCATK, CANONCORR, CCA, KCCA, KCCA2, KERNEL_MAT 
%
%
%  copyright 2004-2006 by K. Veropoulos
%  verop@unr.edu or k_veropoulos@freemail.gr
