function idx = cellfind ( cellvar, pattern )
%CELLFIND Find one string within a cell array of strings.
%   K = CELLFIND(CELLVAR,PATTERN) returns the indices of the elements where
%   the string PATTERN occurs in the cell array of strings CELLVAR.
%   If CELLVAR is a string, then CELLFIND works exactly like STRFIND,
%   returning the starting indices of any occurrences of the string PATTERN
%   in the cell array of strings CELLVAR.
%
%   CELLFIND will always return [] if PATTERN is longer than an element of
%   CELLVAR.
%
%   Examples
%       s = {'How much wood would a woodchuck chuck?', 'I burned the wood'};
%       cellfind(s,'a')    returns  1
%       cellfind(s,'wood') returns  [1 2]
%       cellfind(s,'Wood') returns  []
%       cellfind(s,' ')    returns  [1 2]
%
%       s = 'How much wood would a woodchuck chuck?';
%       cellfind(s,'a')    returns  21
%       cellfind('a',s)    returns  []
%       cellfind(s,'wood') returns  [10 23]
%       cellfind(s,'Wood') returns  []
%       cellfind(s,' ')    returns  [4 9 14 20 22 32]
%
%   See also STRFIND, FINDSTR, STRCMP, STRNCMP, STRMATCH, REGEXP.

%   K. Veropoulos
%   kvero@dri.edu or k_veropoulos@freemail.gr
