function [ eltime, varargout ] = hmsetime ( t_start )
%HMSETIME compute the elapsed time in Hours:Mins:Secs from a given starting
%point in time ('t_start').
%
% Usage: [ eltime, t_end, msg ] = hmsetime ( t_start )
%
% INPUT
%   t_start     starting time as date vector; if 't_start' is given as the
%               current time in date vector format, then 'hmsetime'
%               reports current time only (see example below). 
%
% OUTPUT
%   eltime      a vector containing the elapsed time from 't_start' to
%               current time in days, hours, mins, secs
%   t_end       ending time as date vector (current time)
%	msg         elapsed time as a message string
%
% EXAMPLE
%           t_start = clock;
%           fprintf('Process started at %d:%d:%.2f\n', t_start(4:6));
%           % .... rest of the code
%           [eltime, t_end] = hmsetime(t_start);
%
%           % or
%           % to report task's current completion time
%           hmsetime(clock);
%           
% See also: FULLETIME, CLOCK, ETIME, TIC, TOC
%
%
% K. Veropoulos
% kvero@dri.edu or k_veropoulos@freemail.gr

